      MODULE EGWD_MODULE
      
      IMPLICIT NONE
      INTEGER, PARAMETER  :: ht_dim  = 56 ! Number of vertical levels
!       INTEGER, PARAMETER  :: lon_dim = 64 ! Number of longitudes

      INTEGER, PARAMETER  :: SLEV   = 6  ! Source level
      INTEGER, PARAMETER  :: nh     = 30 ! Number of harmonics
      
      ! Spectral parameters
      REAL*8, PARAMETER   :: PI       = 3.141592653589
      REAL*8, PARAMETER   :: flux0    = 0.00025
      REAL*8, PARAMETER   :: cw       = 35.
      REAL*8, PARAMETER   :: max_cp_y = 80.00 
      REAL*8, PARAMETER   :: kx       = 2.*PI/300.e3 
      REAL*8, PARAMETER   :: max_ht   = 200.e3 !No cal above this height

      ! Physics constants for Earth
      REAL*8, PARAMETER   :: RGAS = 288.7d0  !(J/K/kg)
      REAL*8, PARAMETER   :: GRAV = 9.80d0
      END MODULE EGWD_MODULE

!       PROGRAM egwd_driver
!       use egwd_module
!       implicit none
! 
!       ! Work space
!       REAL*8      :: vy1d(ht_dim)
!       REAL*8      :: vx1d(ht_dim),vx2d(lon_dim,ht_dim)
!       REAL*8      :: temp1d(ht_dim),temp2d(lon_dim,ht_dim) 
!       REAL*8      :: cp1d(ht_dim)
!       REAL*8      :: h(ht_dim)
!       REAL*8      :: pres(ht_dim)  ! Pressure levels
!       REAL*8      :: rho(ht_dim)
!       REAL*8      :: ut_gwd(ht_dim)
!       REAL*8      :: vt_gwd(ht_dim)
!       REAL*8      :: gwht(ht_dim)
!       REAL*8      :: var_tot(ht_dim)
!       REAL*8      :: flux_tot(ht_dim)
! 
!       INTEGER     :: i, k
! 
!       data pres /0.10000E+03,0.71653E+02,  0.51342E+02, 0.36788E+02, 0.26360E+02, 0.18888E+02,&
!            0.13534E+02, 0.96972E+01, 0.69483E+01, 0.49787E+01, 0.35674E+01, 0.25562E+01,&
!            0.18316E+01, 0.13124E+01, 0.94036E+00, 0.67379E+00, 0.48279E+00, 0.34594E+00,&    
!            0.24788E+00, 0.17761E+00, 0.12726E+00, 0.91188E-01, 0.65339E-01, 0.46818E-01,&  
!            0.33546E-01, 0.24037E-01, 0.17223E-01, 0.12341E-01, 0.88427E-02,  0.63361E-02,&  
!            0.45400E-02, 0.32530E-02, 0.23309E-02, 0.16702E-02, 0.11967E-02,  0.85749E-03,&  
!            0.61442E-03, 0.44025E-03, 0.31545E-03,  0.22603E-03, 0.16196E-03,  0.11605E-03,&
!            0.83153E-04, 0.59582E-04, 0.42692E-04,  0.30590E-04, 0.21919E-04,  0.15706E-04,&
!            0.11254E-04, 0.80635E-05, 0.57777E-05,  0.41399E-05, 0.29664E-05,  0.21255E-05,& 
!            0.15230E-05, 0.10913E-05, 0.78193E-06,  0.56028E-06, 0.40146E-06,  0.28766E-06,&
!            0.20612E-06, 0.14769E-06, 0.54331E-07,  0.19987E-07, 0.73530E-08/
! 
!       pres(:) = pres(:)*100.d0
!      
!       ! Read the test input file
!       OPEN(10,file='input2d.dat')
!       READ(10,*) temp2d
!       READ(10,*) vx2d
!       CLOSE(10)
!       !PRINT*,temp2d(10,ht_dim)
!       !PRINT*,vx2d(10,ht_dim)
!       vx1d   = vx2d(10,:)
!       temp1d = temp2d(10,:)
! 
!       DO k= 1, ht_dim
! !        print*,k,temp1d(k),vx1d(k)
!         vy1d(k) = 0.0  ! Meridional wind set to zero for implementation purposes
!         rho(k)  = pres(k)/(RGAS*temp1d(k))
!         cp1d(k) = CP                      ! Assume constant specific heat
!         ! Calculate geometric height above the source level 
!         ! (matters only it, rather than the absolute altitude)
!         IF(k.EQ.1) THEN
!            h(k) = 15d3
!         ELSE
!            h(k) = h(k-1) - (pres(k)-pres(k-1))/ &
!                          ( (rho(k)+rho(k-1))*0.5*GRAV ) ! density at midlevel
!         ENDIF
!       ENDDO
! 
!       CALL EYGwave(rho, vx1d,   vy1d, temp1d, cp1d, h,  &
!                    ut_gwd,  vt_gwd, pres, gwht, &
!                    var_tot, flux_tot)
!       PRINT*, " ========================================================" 
!       PRINT*, " |   THE WHOLE ATMOSPHERE GRAVITY WAVE PARAMETERIZATION |"
!       PRINT*, " |                     [v-10.0]                          |"
!       PRINT*, " |                    June 2018                         |"
!       PRINT*, " |                   Erdal Yiğit                        |"
!       PRINT*, " |                OFFLINE TEST FOR EARTH                |"
!       PRINT*, " ========================================================" 
!       PRINT*,'         Lev    z(km)         GW drag(m/s/s)     var u(m/s) ', &
!        '  heating/cooling (K/s)'
!       PRINT*, "...............................................................&
!            ........................." 
!       DO k=1, ht_dim
!          PRINT*, k, REAL(h(k))/1000., REAL(ut_gwd(k)), &
!               REAL(sqrt(var_tot(k))), REAL(gwht(k))
!       ENDDO
! 
!       STOP
!       end 

      !%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
      !     THE WHOLE ATMOSPHERE GRAVITY WAVE PARAMETERIZATION  
      !                         June 2018
      !                          [v-10.0]
      !%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
      !     
      !     ---------
      !     Reference:
      !     ---------
      !     After Yiğit, E., A. Aylward, and A. S. Medvedev (2008),
      !     ``Parameterization of the effects of vertically propagating gravity
      !     waves for thermosphere general circulation models: Sensitivity
      !     study", JGR, 113, D19106, doi:10.1029/2008JD010135.
      !
      !     ---------
      !     Physics:
      !     ---------
      !     
      !     The parameterization evaluates for a given set of atmospheric
      !     background parameters GW-induced dynamical and thermal effects on
      !     the general circulation of the atmosphere, where ``ut_gwd" and
      !     ``vt_gwd" are the zonal and meridional GW drag and ``gwht" represents
      !     the total GW thermal effects.
      !     
      !     --------------------------------------------
      !     Applications and Publications with the Code:
      !     --------------------------------------------
      !
      !     *** Application of the code for the first time in Earth's General Circulation 
      !     Model:
      !
      !     Yiğit, E., A. S. Medvedev, A. D. Aylward, P. Hartogh, and M. J. Harris (2009), 
      !     Modeling the effects of gravity wave momentum deposition on the general 
      !     circulation above the turbopause, J. Geophys. Res., 114, D07101, 
      !     doi:10.1029/2008JD011132.
      !    
      !     (A) Earth papers: Yiğit et al. (2009, 2012, 2014); Yiğit and Medvedev
      !     (2009, 2010, 2012, 2016, 2017)
      !
      !     (B) Mars: Medvedev et al. (2011a, 2011b, 2013, 2015, 2016), Medvedev and Yiğit
      !     (2012), Yiğit et al. (2015a, 2015b)
      !
      !     (C) Reviewed in: 
      !         1. Yiğit, E., and A. S. Medvedev (2015), Internal wave
      !            coupling processes in Earth’s atmosphere, Adv. Space Res., 55, 983-1003.
      !
      !         2. Yiğit, E., and A. S. Medvedev (2016) Role of gravity waves in vertical 
      !            coupling during sudden stratospheric warmings, Geosci. Lett., 3:27,
      !            doi:10.1186/s40562-016-0056-1 
      !
      !         3. Yiğit and Medvedev (2016), Role of gravity waves in vertical coupling during sudden
      !         stratospheric warmings, Geosci. Lett.3:27, doi:0.1186/s40562-016-0056-1
      !   
      !     (D) Book chapter: 
      !     Yiğit, E., and A. S. Medvedev (2013), ``Extending the Parameterization of
      !     Gravity Waves into the Thermosphere and Modeling Their Effects, in Climate and Weather of the
      !     Sun-Earth System (CAWSES)", edited by F.-J. Lübken, Springer Atmospheric Sciences.
      !
      !     -----------------------
      !     Recent Version History:
      !     -----------------------
      !
      !     [v-10.0] 18 June 2018: provided to Friederike Lilienthal, Christoph Jacobi, Nadja Samtleben
      !     to be implemented in the MUAM model. 
      !    
      ! 
      !    ------------------------------------------------------------------
      !     Some Important General Remarks and Information: Rules of the Road
      !    ------------------------------------------------------------------
      !
      !    *** Code originality: In order to keep track of code versions, the original code
      !    should not be modified significantly other than for implementation and tuning
      !    purposes.
      ! 
      !    *** This GW parameterization cannot be used in combination with other GW
      !    parameterizations.
      ! 
      !    *** It would be highly appreciated if the previous Earth related
      !    applications/publications with the scheme are acknowledged in future publications
      !    using the code. 
      !
      !    *** The developers are keen to be continuously involved in possible collaborations involving,
      !    in particular, the gravity wave work, and other modeling activities and the associated
      !    publications.
      !
      !    *** Please do not distribute the code without the consent of the developers.
      !
      !    ----------------------------------------
      !    How do I run the offline test framework?
      !    ----------------------------------------
      !
      !    All you need to do is to compile the main program and execute it. It will use the
      !    input data, which contains some atmospheric fields, and then output GW parameters.  
      !    For example, just type the following command in the terminal:
      ! 
      !    gfortran Gwave_v09.f90 ; ./a.out 
      !    or
      !    just execute ./run_Gwave
      ! 
      !   ---------------
      !    Further notes:
      !   ---------------
      !    For implementation puposes, 
      !    - the meridional winds are set to zero
      !    - dissipation due to ion friction and eddy viscosity are set to zero. One may turn them
      !      depending on the model. For example for the standard WACCM veddy may be input from the 
      !      GCM into the GW code. The ion dissipation is not be needed. 
      !    - One should use a latitude-dependent gravity, specific heat, and gas constant. You can take
      !      those inputs from your model or calculate them in the GW code.
      !    - For further details and questions contact eyigit@gmu.edu
      !     
      !%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
      
      SUBROUTINE EYGwave(rho, vx1d, vy1d, temp1d, cp1d, h,
     &              ut_gwd, vt_gwd, pres, gwht, var_tot, flux_tot)
      
      USE EGWD_MODULE
      IMPLICIT NONE

      ! Input variables
      REAL*8, INTENT(IN)  :: vy1d(ht_dim)   ! Meridional wind
      REAL*8, INTENT(IN)  :: vx1d(ht_dim)   ! Zonal wind
      REAL*8, INTENT(IN)  :: temp1d(ht_dim) ! Temperature
      REAL*8, INTENT(IN)  :: cp1d(ht_dim)   ! Specific Heat
      REAL*8, INTENT(IN)  :: h(ht_dim)      ! Geopotential height (in m)
      REAL*8, INTENT(IN)  :: pres(ht_dim)   ! Pressure (in Pa)
      REAL*8, INTENT(IN)  :: rho(ht_dim)    ! Density
      REAL*8              :: v_eddy(ht_dim) = 0.0 ! Eddy viscosity  
      REAL*8              :: eden(ht_dim)   = 0.0  
      
      ! Output variables
      REAL*8, INTENT(OUT) :: ut_gwd(ht_dim) ! Zonal GW drag
      REAL*8, INTENT(OUT) :: vt_gwd(ht_dim) ! Meridional GW drag
      
      REAL*8, INTENT(OUT) :: gwht(ht_dim)    ! GW heating
      REAL*8              :: scht1d(ht_dim)  ! 1D scale height
      
      REAL*8 :: m_vis(ht_dim),              ! molecular kinematic viscosity
     &          var_tot(ht_dim),    
     &          flux_tot(ht_dim)
      
      ! mid-point variables
      REAL*8 :: temp1d_m(ht_dim)
      REAL*8 :: u_source_m(ht_dim)
      REAL*8 :: pres_m(ht_dim)
      REAL*8 :: rho_m(ht_dim)
      REAL*8 :: h_m(ht_dim)
      REAL*8 :: eden_m(ht_dim)
      REAL*8 :: scht1d_m(ht_dim)

      REAL*8 :: drag(ht_dim,nh)

      REAL   :: phasespeed(nh)              
      REAL*8 :: uw_mom(nh) = 0.
      REAL*8 :: brunt(ht_dim) = 0.02        
      REAL*8 :: theta(ht_dim), thetap(ht_dim)
      INTEGER :: b_lev(nh), c_lev(nh)
      REAL*8 :: dz(ht_dim), rho_pr(ht_dim)

! Dissipation variables
      REAL*8 :: tau(ht_dim, nh)     
      REAL*8 :: beta(ht_dim, nh)           
      REAL*8 :: beta_dif(ht_dim,nh)  = 0.   
      REAL*8 :: beta_mol(ht_dim,nh)  = 0.   
      REAL*8 :: beta_nc(ht_dim,nh)   = 0.   
      REAL*8 :: beta_non(ht_dim,nh) ! = 0.   
      REAL*8 :: beta_eddy(ht_dim,nh) = 0.  
      REAL*8 :: beta_ion(ht_dim,nh)  = 0.  

      REAL*8 :: fac1, fac2  

      REAL*8 :: alpha(ht_dim)        = 0. 
      REAL*8 :: vin(ht_dim)          = 0. 


      INTEGER :: i, j, k, n, nd, m

      REAL*8 :: c_int(ht_dim,nh) 
      REAL*8 :: sign_c(ht_dim,nh)
      REAL*8 :: flux(ht_dim,nh)
      REAL*8 :: up(ht_dim,nh)
      REAL*8 :: upSq(ht_dim,nh)

! Total horizontal wind variance at the source level
      REAL*8 :: sigmaSq_s=0., rms

      INTEGER :: sgn(nh)

! Nonlinearity parameters
      REAL*8 :: sigma(ht_dim,nh)=0.
      REAL*8 :: sigmaSq(ht_dim,nh)=0.
      REAL*8 :: alpha_ins(ht_dim,nh)=0.

      REAL*8, PARAMETER   :: S2  = 1.4142136d0 
      REAL*8, PARAMETER   :: S2P = 2.5066283d0 

! Anisotropy variables
      REAL*8  :: u_source(ht_dim), gwd(ht_dim), gwh(ht_dim)
      REAL*8  :: xv, yv !EPS

      tau(:,:)     = 1.;    gwd(:)       = 0.;   gwh(:)       = 0.
      drag(:,:)    = 0.
      sigmaSq(:,:) = 0.;    beta(:,:)    = 0.;   flux_tot(:)  = 0.
      var_tot(:)   = 0.;    upSq(:,:)    = 0.;   up(:,:)      = 0.
      flux(:,:)    = 0.;    beta_non(:,:)= 0.
    
! Project the upper level winds onto the source level winds
      PROJECTION : DO n = SLEV, ht_dim
       IF(n.eq.SLEV) THEN
          u_source(n) = SQRT(vy1d(n)*vy1d(n) + vx1d(n)*vx1d(n))
          IF(u_source(n).eq.0.) u_source(n) = 1.
          yv = vy1d(n)/u_source(n)
          xv = vx1d(n)/u_source(n)
       ENDIF
          u_source(n) = vy1d(n)*yv + vx1d(n)*xv
      ENDDO PROJECTION

      theta(:) = temp1d(:)*(pres(1)/pres(:))**(RGAS/cp1d(:))
      scht1d(:)= temp1d(:)*RGAS/GRAV

! Mid-point values of model variables
      MID_POINT : DO n = 1, ht_dim-1
         temp1d_m(n)   = 0.5*(temp1d(n)   + temp1d(n+1))
         u_source_m(n) = 0.5*(u_source(n) + u_source(n+1))
         pres_m(n)     = 0.5*(pres(n)     + pres(n+1))
         rho_m(n)      = 0.5*(rho(n)      + rho(n+1))
         h_m(n)        = 0.5*(h(n)        + h(n+1))
         eden_m(n)     = 0.5*(eden(n)     + eden(n+1))
         scht1d_m(n)   = 0.5*(scht1d(n)   + scht1d(n+1))
      ENDDO MID_POINT

! Brunt frequency and background parameters
      BACKGROUND1: DO n = 1, ht_dim-1
         dz(n)     = h(n+1) - h(n)               
         rho_pr(n) = (rho(n+1) - rho(n))/dz(n)   

         m_vis(n) = 4.5E-05*(temp1d_m(n)/1000.0)**0.71/rho_m(n) 
         vin(n)   = 7.22e-17*temp1d_m(n)**0.37*eden_m(n)        

      ENDDO BACKGROUND1
 
      BACKGROUND2: DO n=1, ht_dim-1
         thetap(n) = (theta(n+1) - theta(n))/dz(n) 
         brunt(n)  = (ABS((2*GRAV/(theta(n)+theta(n+1)))*thetap(n)))
         brunt(n)  = sqrt(brunt(n))
      ENDDO BACKGROUND2


      SPECTRUM : DO i = 1, nh
         IF(i.eq.1)  phasespeed(i) = -max_cp_y 
         IF(i.GE.2)  phasespeed(i) = phasespeed(i-1)              
     &               *((max_cp_y/2)**(-1./((nh/2.)-1.)))
         
         IF(i.eq.(nh/2+1))   phasespeed(i) = 2. 
         IF(i.GE.(nh/2+2)) phasespeed(i) = phasespeed(i-1)        
     &                     *((max_cp_y/2)**(1./((nh/2.)-1.)))
      ENDDO SPECTRUM

      SPECTRUM2: DO i = 1, nh

         sgn(i)    = phasespeed(i)/ABS(phasespeed(i))
         uw_mom(i) = sgn(i)*(flux0*EXP(-(phasespeed(i)/cw)**2))

         tau(SLEV,i)  = 1.
         flux(SLEV,i) = uw_mom(i)
         flux_tot(SLEV)=flux_tot(SLEV) + flux(SLEV,i)
         c_int(SLEV,i)  = phasespeed(i) - u_source_m(SLEV)
         IF(abs(c_int(SLEV,i)) .ge. brunt(SLEV)*100.) upSq(SLEV,i)      
     &              = ABS(uw_mom(i))*brunt(SLEV)/(kx*ABS(c_int(SLEV,i)))
         IF(ABS(upSq(SLEV,i)).GT.0.) up(SLEV,i) = SQRT(upSq(SLEV,i))
         IF (c_int(SLEV,i).NE.0) sign_c(SLEV,i) =  
     &              c_int(SLEV,i)/ABS(c_int(SLEV,i))
         IF (c_int(SLEV,i).EQ.0) sign_c(SLEV,i) = 1.

         var_tot(SLEV) = var_tot(SLEV) + upSq(SLEV,i)
      ENDDO SPECTRUM2

      c_lev(:) = -1
      b_lev(:) = -1

      HT_LOOP : DO n = SLEV+1, ht_dim-1

        PS_LOOP : DO i = 1, nh
          
          IF(h(n) > max_ht) CYCLE
          
          c_int(n,i)  = phasespeed(i) - u_source_m(n)
          IF(c_int(n,i).NE.0) sign_c(n,i) = c_int(n,i)/ABS(c_int(n,i))
          IF(c_int(n,i).EQ.0) sign_c(n,i) = 1.
          
          CRITICAL : IF(c_lev(i).LT.0                        
     &                 .AND. (sign_c(n,i).NE.sign_c(n-1,i)   
     &                 .AND. c_int(n,i).NE.0.)) THEN       
                       c_lev(i) = n
                       flux(n,i)  = 0.

           ELSE IF (c_lev(i).LT.0) THEN
             fac1      = 2.*brunt(n)*brunt(n)*brunt(n)   
     &                       /(kx*c_int(n,i)**4)
             fac2      = brunt(n)/(kx*c_int(n,i)*c_int(n,i))
!################################################################
!	       EPS=2.*(m_vis(n)+v_eddy(n))*
!     &           brunt(n)*brunt(n)/kx/abs(c_int(n,i))**3
!	       IF(EPS.ge.1.) fac1 = fac1/EPS/EPS
!################################################################            

             beta(n,i) = fac1*(m_vis(n)+v_eddy(n))       
     &                  + fac2*(vin(n)+alpha(n))

             NON_LINEARITY : DO j = 1, nh
                c_int(n,j) = phasespeed(j) - u_source_m(n)
                IF (ABS(c_int(n,i)) .GE. ABS(c_int(n,j))) THEN
                   sigmaSq(n,i) = sigmaSq(n,i) + upSq(n-1,j)
                ENDIF
             ENDDO NON_LINEARITY
                
             IF(sigmaSq(n,i).ge.1e-36) THEN
                sigma(n,i)     = SQRT(sigmaSq(n,i))
                alpha_ins(n,i) = ABS(c_int(n,i))/S2/sigma(n,i)
                IF(alpha_ins(n,i).GE.1e10) THEN
                   beta_non(n,i) = 0.
                ELSE
                   beta_non(n,i)  = S2P*brunt(n)/sigma(n,i)    
     &                        *EXP(-alpha_ins(n,i)*alpha_ins(n,i))
                ENDIF
             ENDIF
                
             beta(n,i) = beta(n,i) + beta_non(n,i)
             tau(n,i)  = tau(n-1,i)    
     &                  *EXP(-dz(n)*(beta(n,i)+beta(n-1,i))*0.5)
             flux(n,i) = uw_mom(i)*rho(SLEV)/rho(n)*tau(n,i)
             upSq(n,i) = ABS(flux(n,i))*brunt(n)/kx/ABS(c_int(n,i))
             IF(ABS(upSq(n,i)).GT.0.) up(n,i) = SQRT(upSq(n,i))
                
             drag(n,i) = beta(n,i)*flux(n,i)

             IF(alpha_ins(n,i).LT.0.75) drag(n,i) = 0.

             flux_tot(n) = flux_tot(n) + flux(n,i) 
             var_tot(n)  = var_tot(n)  + upSq(n,i)
             gwd(n)      = gwd(n) + drag(n,i)

             gwh(n)      = gwh(n) + drag(n,i)*c_int(n,i)/cp1d(n) +   
     &                  ((scht1d_m(n)/2./RGAS/rho_m(n))*                 
     &             ( rho_pr(n)*c_int(n,i)*drag(n,i)  +              
     &             rho_m(n)*((c_int(n,i)-c_int(n-1,i))/dz(n))*drag(n,i)+  
     &             rho_m(n)*c_int(n,i)*((drag(n,i)-drag(n-1,i))/dz(n)))) 
                  
          ENDIF CRITICAL
        ENDDO PS_LOOP
      ENDDO HT_LOOP
    

      BACK_INT : DO n=2, ht_dim-1
         gwd(n) = 0.5*(gwd(n) + gwd(n-1))
         gwh(n) = 0.5*(gwh(n) + gwh(n-1))
      ENDDO BACK_INT

      SMOOTH : DO n = 2, ht_dim-1
         gwd(n)  = (gwd(n-1)  + 2.*gwd(n)  + gwd(n+1))*0.25
         gwh(n)  = (gwh(n-1)  + 2.*gwh(n)  + gwh(n+1))*0.25
      ENDDO SMOOTH

      gwd(ht_dim) = gwd(ht_dim-1)
    
      BACK_PROJECT : DO n=SLEV, ht_dim
         ut_gwd(n) = xv * gwd(n) 
         vt_gwd(n) = yv * gwd(n)
         gwht(n)   = gwh(n)
      ENDDO BACK_PROJECT
      
      RETURN
      END SUBROUTINE EYGwave
